==> common-application-1.2.4-sources.jar: be/yildizgames/common/application/helper/splashscreen/EmptySplashScreen.java <==
/*
 * MIT License
 *
 * Copyright (c) 2019 Grégory Van den Borre
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package be.yildizgames.common.application.helper.splashscreen;

/**
 * @author Grégory Van den Borre
 */
public class EmptySplashScreen implements SplashScreen {

    public EmptySplashScreen() {
        super();
    }

    @Override
    public void display() {
        //Does nothing.
    }

    @Override
    public void close() {
        //Does nothing.
    }

    @Override
    public void setName(String name) {
        //Does nothing.
    }
}

==> common-application-1.2.7-sources.jar: be/yildizgames/common/application/helper/splashscreen/EmptySplashScreen.java <==
/*
 * MIT License
 *
 * Copyright (c) 2019 Grégory Van den Borre
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package be.yildizgames.common.application.helper.splashscreen;

/**
 * @author Grégory Van den Borre
 */
public class EmptySplashScreen extends UpdateSplashScreen {

    public EmptySplashScreen() {
        super();
    }

    @Override
    public void display() {
        //Does nothing.
    }

    @Override
    public void close() {
        //Does nothing.
    }

    @Override
    public void setName(String name) {
        //Does nothing.
    }

    @Override
    public void setProgress(int percent) {
        //Does nothing.
    }

    @Override
    public void setCurrentLoading(String name) {
        //Does nothing.
    }
}
